import { Component } from '@angular/core';

import { Platform } from '@ionic/angular';
import { SplashScreen } from '@ionic-native/splash-screen/ngx';
import { StatusBar } from '@ionic-native/status-bar/ngx';
import { OneSignal } from '@ionic-native/onesignal/ngx';
import { Storage } from '@ionic/storage';
import { ApiService } from './services/api.service';

@Component({
  selector: 'app-root',
  templateUrl: 'app.component.html',
  styleUrls: ['app.component.scss']
})
export class AppComponent {
  constructor(
    private platform: Platform,
    private splashScreen: SplashScreen,
    private statusBar: StatusBar,
    private oneSignal: OneSignal,
    private storage: Storage,
    private apiService: ApiService
  ) {
    this.initializeApp();
  }

  initializeApp() {
    this.platform.ready().then(() => {
      this.statusBar.styleLightContent();
      this.statusBar.backgroundColorByHexString('#55b1d3');
      this.splashScreen.hide();
      this.setupPush()
    });
  }

  setupPush() {
    if (this.platform.is('cordova')) {
      // I recommend to put these into your environment.ts
      this.oneSignal.startInit('a38177ad-d75a-4b6e-ab65-96a4439aa300', '1086115696321');

      this.oneSignal.inFocusDisplaying(this.oneSignal.OSInFocusDisplayOption.None);

      // Notifcation ถ้าอยู่ในระหว่างเปิดโปรแกรม HHC+ อยู่ แจ้งรายละเอียดชื่อผู้ป่วยและสถานพยาบาลที่ส่ง แจ้งเตือนการดูข้อมูล
      this.oneSignal.handleNotificationReceived().subscribe(data => {
        let msg = data.payload.body;
        let title = data.payload.title;
        let additionalData = data.payload.additionalData;
        this.showAlert(title, msg, additionalData.id, additionalData.cid);
      });

      // Notification หากโปรแกรมปิดอยู่และถูกคลิกขึ้นมาจะเปิดโปรแกรม แจ้งเตือนการดูข้อมูล
      this.oneSignal.handleNotificationOpened().subscribe(data => {
        // Just a note that the data is a different place here!
        let additionalData = data.notification.payload.additionalData;

        this.showAlert('ยืนยันการดำเนินการ', 'คุณต้องการดูรายละเอียดข้อมูลของผู้ป่วยรายนี้หรือไม่', additionalData.id, additionalData.cid);
      });

      this.oneSignal.getIds()
        .then((uuid: any) => {
          // this.id = uuid.userId
          // this.notify.setSubscribed(uuid.userId).subscribe(
          //   (data) => {
          // this.notify.getFistNotify(uuid.userId).subscribe()
          this.storage.get('user').then(user => {
            this.apiService.putMobileAlert(user.cid, user.fullname, 'NCDatHOME', uuid.userId, user.token).subscribe()
          })
          // })
        })// console.log(uuid))
        .catch((error: any) => console.log(error));
      this.oneSignal.endInit();
    }
  }

  // async 
  showAlert(title, msg, id, cid) {
    // const alert = await this.alertCtrl.create({
    //   header: title,
    //   subHeader: msg,
    //   buttons: [
    //     {
    //       text: `ปิด`,
    //       role: 'cancel',
    //       cssClass: 'secondary',
    //       handler: () => {
    //       }
    //     },
    //     {
    //       text: `ดูข้อมูล`,
    //       cssClass: 'primary',
    //       handler: () => {
    //         // this.navController.navigateForward(`/patient-inhomesss/${id}/${cid}`)
    //       }
    //     }
    //   ]
    // })
    // alert.present();
  }
}
