import { Component, ViewChild, OnInit, Inject, LOCALE_ID } from '@angular/core';
import { AlertController } from '@ionic/angular';
import { formatDate } from '@angular/common';

import { CalendarComponent } from 'ionic2-calendar/calendar';
import { ApiService } from '../services/api.service';
import { Storage } from '@ionic/storage';
import { NavController, NavParams, ActionSheetController, LoadingController } from '@ionic/angular';
@Component({
  selector: 'app-calendar',
  templateUrl: './calendar.page.html',
  styleUrls: ['./calendar.page.scss'],
})
export class CalendarPage implements OnInit {
  @ViewChild(CalendarComponent, { read: false, static: false }) myCal: CalendarComponent;

  event = {
    cid: '',
    fname: '',
    lname: '',
    sex: '' ,
    title: '',
    desc: '',
    startTime: '',
    endTime: '',
    allDay: false
  };

  appoint: any;

  eventSource = []

  calendar = {
    mode: 'month',
    currentDate: new Date(),
    locale: 'th-TH',
  }

  viewTitle;

  constructor(
    private alertCtrl: AlertController, @Inject(LOCALE_ID)
    private locale: string,
    private serviceService: ApiService,
    private storage: Storage,
    public navController: NavController,
    public actionSheetController: ActionSheetController
  ) { }

  today() {
    this.calendar.currentDate = new Date();
  }

  next() {
    var swiper = document.querySelector('.swiper-container')['swiper'];
    swiper.slideNext();
  }

  back() {
    var swiper = document.querySelector('.swiper-container')['swiper'];
    swiper.slidePrev();
  }

  // Selected date reange and hence title changed
  onViewTitleChanged(title) {
    this.viewTitle = title;
  }

  onTimeSelected(){
  }

  // Calendar event was clicked
  async onEventSelected(event) {
    // Use Angular date pipe for conversion
    // let start = formatDate(event.startTime, 'medium', this.locale);
    // let end = formatDate(event.endTime, 'medium', this.locale);

    // const alert = await this.alertCtrl.create({
    //   header: event.title,
    //   subHeader: event.desc,
    //   // message: 'From: ' + start + '<br><br>To: ' + end,
    //   buttons: ['OK']
    // });
    // alert.present();
    this.presentActionSheet(event.cid, event.fname, event.lname, event.sex);
  }

  ngOnInit() {
    this.resetEvent();
    this.addEvent();

  }

  resetEvent() {
    this.event = {
      cid: '',
      fname: '',
      lname: '',
      sex: '' ,
      title: '',
      desc: '',
      startTime: new Date().toISOString(),
      endTime: new Date().toISOString(),
      allDay: false
    };
  }

  addEvent() {
    this.storage.get('user').then(user => {
      this.serviceService.getAppoint(user.cid).subscribe(
        data => {
          console.log(data.rows);
          // this.eventSource = data.rows
          for (let i = 0; i < data.rows.length; i++) {
            console.log(data.rows[i]);
            let eventCopy = {
              // title: 'test',
              // startTime:  '2019-12-21 07:00AM',
              // endTime: '2019-12-21 07:00AM',
              // allDay: true,
              // desc: 'desc'
              title: data.rows[i].title,
              startTime: new Date(data.rows[i].startTime),
              endTime: new Date(data.rows[i].endTime),
              allDay: true,
              desc: '',
              cid: data.rows[i].cid,
              fname: data.rows[i].fname,
              lname: data.rows[i].lname,
              sex: data.rows[i].sex
            }

            if (eventCopy.allDay) {
              // let start = '2019-12-21 07:00AM';
              // let end = '2019-12-21 07:00AM';
              let start = eventCopy.startTime;
              let end = eventCopy.endTime;

              // eventCopy.startTime = '2019-12-21 07:00AM';
              // eventCopy.endTime = '2019-12-21 07:00AM';
              eventCopy.startTime = new Date(Date.UTC(start.getUTCFullYear(), start.getUTCMonth(), start.getUTCDate()));
              eventCopy.endTime = new Date(Date.UTC(end.getUTCFullYear(), end.getUTCMonth(), end.getUTCDate() + 1));
            }

            this.eventSource.push(eventCopy);
          }
        }
      )
      // this.eventSource.push(eventCopy);
      // this.myCal.loadEvents();
      this.resetEvent();
    })

  }
  async presentActionSheet(cid: any, fname: any, lname: any, sex: any) {
    const actionSheet = await this.actionSheetController.create({
      //header: 'เมนู',
      mode: 'ios',
      buttons: [{
        text: 'บันทึกข้อมูล',
        role: 'destructive',
        icon: 'create',
        handler: () => {
          // console.log('Delete clicked');
          this.navController.navigateForward('/screen/' + cid + '/' + fname + '/' + lname + '/' + sex);
          // console.log(fname);

        }
      },
      {
        text: 'ประวัติ',
        icon: 'contact',
        handler: () => {
          // console.log('Play clicked');
          this.navController.navigateForward('/history/' + cid + '/' + fname + '/' + lname + '/' + sex)
        }
      }, {
        text: 'ยกเลิก',
        icon: 'close',
        role: 'cancel',
        handler: () => {
          // console.log('Cancel clicked');
        }
      }]
    });
    await actionSheet.present();
  }

}