import { Component, OnInit, ViewChild, ElementRef } from '@angular/core';
import { NavParams, ModalController, AlertController, ToastController, Platform } from '@ionic/angular';
import { Storage } from '@ionic/storage';
import { ApiService } from '../services/api.service';

@Component({
  selector: 'app-image-preview',
  templateUrl: './image-preview.page.html',
  styleUrls: ['./image-preview.page.scss'],
})
export class ImagePreviewPage implements OnInit {
  myAuthen: any

  @ViewChild('slider', { read: ElementRef, static: false }) slider: ElementRef;
  img: any;
  userid: any;

  sliderOpts = {
    zoom: {
      maxRatio: 5
    }
  };

  constructor(
    private navParams: NavParams,
    private modalController: ModalController,
    private storage: Storage,
    private alertCtrl: AlertController,
    private toastController: ToastController,
    private apiService: ApiService,
    private platform: Platform
  ) { }

  ngOnInit() {
    this.img = this.navParams.get('img');
    this.userid = this.navParams.get('userid');
    this.platform.ready().then(() => {
      this.storage.get(`user`).then((authen) => {
        if (authen) {
          this.myAuthen = authen
        }
        // this.storage.get(`run-token`).then((token) => {

        //   let d = new Date();
        //   let dformat = d.getFullYear() + "-" +
        //     ("00" + (d.getMonth() + 1)).slice(-2) + "-" +
        //     ("00" + d.getDate()).slice(-2) + " " +
        //     ("00" + d.getHours()).slice(-2) + ":" +
        //     ("00" + d.getMinutes()).slice(-2) + ":" +
        //     ("00" + d.getSeconds()).slice(-2)
        //   let myForm = { 'user_id': authen.username, 'component': 'image-preview', 'datetime': dformat , 'application' : '500kRUN' }
        //   if (this.platform.is('ios')) {
        //     myForm['platform'] = 'ios'
        //   }
        //   if (this.platform.is('android')) {
        //     myForm['platform'] = 'android'
        //   }
        //   if (this.platform.is('desktop')) {
        //     myForm['platform'] = 'desktop'
        //   }
        //   this.apiService.setData('log', myForm, token).subscribe()
        // })
      })
    });
  }

  zoom(zoomIn: boolean) {
    let zoom = this.slider.nativeElement.swiper.zoom;
    if (zoomIn) {
      zoom.in();
    } else {
      zoom.out();
    }
  }

  close() {
    this.modalController.dismiss();
  }

  delete(img: string) {
    this.storage.get(`user`).then((token) => {
      let alert = this.alertCtrl.create({
        subHeader: 'ยืนยันการลบรูปภาพนี้',
        message: 'เมื่อลบรูปภาพนี้แล้วจะไม่สามารถกู้คืนภาพนี้ได้อีก!!! ท่านต้องการลบภาพนี้หรือไม่?',
        buttons: [{
          text: 'ลบ',
          handler: () => {
            this.apiService.deletePhoto(img, token.token).subscribe(
              (res) => {
                let toast = this.toastController.create({
                  message: res['message'],
                  duration: 3000,
                  position: 'bottom'
                });
                toast.then(toast => toast.present());
                this.modalController.dismiss(true);
              }
            )
          }
        }, {
          text: 'ยกเลิก',
          handler: () => {
            // console.log(img);
          }
        }]
      }).then(alert => alert.present())
    })
  }

}
