import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable, from, BehaviorSubject } from 'rxjs';
import { Platform } from '@ionic/angular';
import { Storage } from '@ionic/storage';

@Injectable({
  providedIn: 'root'
})
export class AuthenService {
  authenticationState = new BehaviorSubject(false);

  constructor(
    private http: HttpClient,
    private platform: Platform,
    private storage: Storage,
  ) {
    this.platform.ready().then(() => {
      this.checkToken();
    });
  }

  checkToken() {
    return new Promise((resolve, reject) => {
      this.storage.get('user')
        .then(res => {
          if (res) {
            this.authenticationState.next(true);
          }
          resolve(res);
        })
        .catch(error => {
          reject(error);
        });
    });
  }

  isAuthenticated() {
    return new Promise( (resolve, reject) => {
      this.checkToken()
      .then( res => {
        resolve(this.authenticationState.value);
      })
      .catch( error => {
        reject(error);
      });
    });
  }

  doAuthen(username: string, password: string): Observable<any> {
    return this.http.post<any>('http://203.157.145.19:3002/login', {
      username: username,
      password: password
    })
  }

}
